Class: FlowLink
- Inherits:
-
Object
- Object
- FlowLink
- Defined in:
- lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb
Overview
A class defining a navigation step that is needed as part of a flow. These assume that their navigation is done via links, not buttons/divs/etc.
Instance Attribute Summary collapse
-
#destination ⇒ Object
parent_page is the page within which the desired link.
-
#name ⇒ Object
parent_page is the page within which the desired link.
-
#parent_page ⇒ Object
parent_page is the page within which the desired link.
-
#verification ⇒ Object
parent_page is the page within which the desired link.
Instance Method Summary collapse
-
#initialize(destination, name, parent_page) ⇒ FlowLink
constructor
can be found destination is the name of the page that the browser will arrive at after performing this navigation.
- #to_s ⇒ Object
Constructor Details
#initialize(destination, name, parent_page) ⇒ FlowLink
can be found destination is the name of the page that the browser will arrive at after performing this navigation. verification is a FlowVerify object that is defined such that it can only pass if it matches the defined field on the destination page TODO enable mechanism such that one can simply state flow.goto(destination) and all flows will be scanned for the flow that will take us there, then that flow will be executed.
222 223 224 225 226 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 222 def initialize(destination, name, parent_page) @destination = destination @name = name @parent_page = parent_page end |
Instance Attribute Details
#destination ⇒ Object
parent_page is the page within which the desired link
214 215 216 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 214 def destination @destination end |
#name ⇒ Object
parent_page is the page within which the desired link
214 215 216 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 214 def name @name end |
#parent_page ⇒ Object
parent_page is the page within which the desired link
214 215 216 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 214 def parent_page @parent_page end |
#verification ⇒ Object
parent_page is the page within which the desired link
214 215 216 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 214 def verification @verification end |
Instance Method Details
#to_s ⇒ Object
228 229 230 231 232 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 228 def to_s s = "" s += "Flow destination : #{@destination}. Link ID : #{@name}. Parent page : #{@parent_page}" s end |