Class: FlowPrecondition
- Inherits:
-
Object
- Object
- FlowPrecondition
- Defined in:
- lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb
Overview
A class defining a flow that must be executed as a precondition to the flow this object belongs to
Instance Attribute Summary collapse
-
#precondition_flow ⇒ Object
precondition_flow is the name of the precondition flow that must be executed.
Instance Method Summary collapse
-
#execute_precondition_flow(custom_values_hash = {}) ⇒ Object
TODO : need success & madatory field flags here?.
-
#initialize(precondition_flow) ⇒ FlowPrecondition
constructor
A new instance of FlowPrecondition.
- #to_s ⇒ Object
Constructor Details
#initialize(precondition_flow) ⇒ FlowPrecondition
Returns a new instance of FlowPrecondition.
189 190 191 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 189 def initialize(precondition_flow) @precondition_flow = precondition_flow end |
Instance Attribute Details
#precondition_flow ⇒ Object
precondition_flow is the name of the precondition flow that must be executed
187 188 189 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 187 def precondition_flow @precondition_flow end |
Instance Method Details
#execute_precondition_flow(custom_values_hash = {}) ⇒ Object
TODO : need success & madatory field flags here?
200 201 202 203 204 205 206 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 200 def execute_precondition_flow(custom_values_hash = {}) # find flow from name # TODO : flows all stored in @flow (CeresFlow.new()). Gaining access to this feels wrong... # execute flow end |
#to_s ⇒ Object
193 194 195 196 197 |
# File 'lib/taft_files/framework/zznamezz/watir/flows/flow_objects.rb', line 193 def to_s s = "" s += "Precondition Flow : #{@precondition_flow}" s end |